@@ -13,34 +13,59 @@
 #'   \code{\link[mapproj]{mapproject}}
 #' @param orientation projection orientation, which defaults to 
 #'  \code{c(90, 0, mean(range(x)))}.  This is not optimal for many
-#'  projections, so you will have to supply your own.
+#'  projections, so you will have to supply your own. See
+#'  \code{\link[mapproj]{mapproject}} for more information.
 #' @param xlim manually specific x limits (in degrees of lontitude)
 #' @param ylim manually specific y limits (in degrees of latitude)
 #' @export
 #' @examples
 #' if (require("maps")) {
 #' # Create a lat-long dataframe from the maps package
-#' nz <- data.frame(map("nz", plot=FALSE)[c("x","y")])
-#' (nzmap <- qplot(x, y, data=nz, geom="path"))
-#' 
+#' nz <- map_data("nz")
+#' nzmap <- ggplot(nz, aes(x=long, y=lat, group=group)) +
+#'   geom_polygon(fill="white", colour="black")
+#'
+#' # Use cartesian coordinates
+#' nzmap
+#' # With default mercator projection
 #' nzmap + coord_map()
-#' nzmap + coord_map(project="cylindrical")
-#' nzmap + coord_map(project='azequalarea',orientation=c(-36.92,174.6,0))
+#' # Other projections
+#' nzmap + coord_map("cylindrical")
+#' nzmap + coord_map("azequalarea",orientation=c(-36.92,174.6,0))
 #' 
-#' states <- data.frame(map("state", plot=FALSE)[c("x","y")])
-#' (usamap <- qplot(x, y, data=states, geom="path"))
+#' states <- map_data("state")
+#' usamap <- ggplot(states, aes(x=long, y=lat, group=group)) +
+#'   geom_polygon(fill="white", colour="black")
+#'
+#' # Use cartesian coordinates
+#' usamap
+#' # With mercator projection
 #' usamap + coord_map()
 #' # See ?mapproject for coordinate systems and their parameters
-#' usamap + coord_map(project="gilbert")
-#' usamap + coord_map(project="lagrange")
+#' usamap + coord_map("gilbert")
+#' usamap + coord_map("lagrange")
 #'
 #' # For most projections, you'll need to set the orientation yourself
 #' # as the automatic selection done by mapproject is not available to
 #' # ggplot
-#' usamap + coord_map(project="orthographic")
-#' usamap + coord_map(project="stereographic")
-#' usamap + coord_map(project="conic", lat0 = 30)
-#' usamap + coord_map(project="bonne", lat0 = 50)
+#' usamap + coord_map("orthographic")
+#' usamap + coord_map("stereographic")
+#' usamap + coord_map("conic", lat0 = 30)
+#' usamap + coord_map("bonne", lat0 = 50)
+#'
+#' # World map, using geom_path instead of geom_polygon
+#' world <- map_data("world")
+#' worldmap <- ggplot(world, aes(x=long, y=lat, group=group)) +
+#'   geom_path() +
+#'   scale_y_continuous(breaks=(-2:2) * 30) +
+#'   scale_x_continuous(breaks=(-4:4) * 45)
+#'
+#' # Orthographic projection with default orientation (looking down at North pole)
+#' worldmap + coord_map("ortho")
+#' # Looking up up at South Pole
+#' worldmap + coord_map("ortho", orientation=c(-90, 0, 0))
+#' # Centered on New York (currently has issues with closing polygons)
+#' worldmap + coord_map("ortho", orientation=c(41, -74, 0))
 #' }
 coord_map <- function(projection="mercator", ..., orientation = NULL, xlim = NULL, ylim = NULL) { 
   try_require("mapproj")
@@ -137,6 +162,15 @@ coord_train.map <- function(coord, scales) {
 coord_render_bg.map <- function(coord, details, theme) {    
   xrange <- expand_range(details$x.range, 0.2)
   yrange <- expand_range(details$y.range, 0.2)
+
+  # Limit ranges so that lines don't wrap around globe
+  xmid <- mean(xrange)
+  ymid <- mean(yrange)
+  xrange[xrange < xmid - 180] <- xmid - 180
+  xrange[xrange > xmid + 180] <- xmid + 180
+  yrange[yrange < ymid - 90] <- ymid - 90
+  yrange[yrange > ymid + 90] <- ymid + 90
+
   xgrid <- with(details, expand.grid(
     y = c(seq(yrange[1], yrange[2], len = 50), NA),
     x = x.major
